aboutsummaryrefslogtreecommitdiffstats
path: root/os/hal/src
diff options
context:
space:
mode:
Diffstat (limited to 'os/hal/src')
-rw-r--r--os/hal/src/sdc.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/os/hal/src/sdc.c b/os/hal/src/sdc.c
index 6ae84c98c..7722a0eb7 100644
--- a/os/hal/src/sdc.c
+++ b/os/hal/src/sdc.c
@@ -454,8 +454,8 @@ sdcflags_t sdcGetAndClearErrors(SDCDriver *sdcp) {
* @param[in] sdcp pointer to the @p SDCDriver object
*
* @return The operation status.
* @retval FALSE the operation succeeded.
* @retval TRUE the operation failed.
*
* @api
*/
@@ -466,13 +466,13 @@ bool_t sdcSync(SDCDriver *sdcp) {
chSysLock();
if (sdcp->state != SDC_READY) {
chSysUnlock();
- return TRUE;
+ return CH_FAILED;
}
chSysUnlock();
/* TODO: implement.*/
- return FALSE;
+ return CH_SUCCESS;
}
/**
@@ -482,8 +482,8 @@ bool_t sdcSync(SDCDriver *sdcp) {
* @param[out] bdip pointer to a @p BlockDeviceInfo structure
*
* @return The operation status.
* @retval FALSE the operation succeeded.
* @retval TRUE the operation failed.
*
* @api
*/
@@ -495,14 +495,14 @@ bool_t sdcGetInfo(SDCDriver *sdcp, BlockDeviceInfo *bdip) {
chSysLock();
if (sdcp->state != SDC_READY) {
chSysUnlock();
- return TRUE;
+ return CH_FAILED;
}
chSysUnlock();
bdip->blk_num = sdcp->capacity;
bdip->blk_size = MMCSD_BLOCK_SIZE;
- return FALSE;
+ return CH_SUCCESS;
}
#endif /* HAL_USE_SDC */
@@ -454,8 +454,8 @@ sdcflags_t sdcGetAndClearErrors(SDCDriver *sdcp) {
*
* @return The operation status.
- * @retval FALSE the operation succeeded.
- * @retval TRUE the operation failed.
+ * @retval CH_SUCCESS the operation succeeded.
+ * @retval CH_FAILED the operation failed.
*
* @api
@@ -482,8 +482,8 @@ bool_t sdcSync(SDCDriver *sdcp) {
*
* @return The operation status.
- * @retval FALSE the operation succeeded.
- * @retval TRUE the operation failed.
+ * @retval CH_SUCCESS the operation succeeded.
+ * @retval CH_FAILED the operation failed.
*
* @api